"""Reference to SnykGroupRoleV1 model."""


class SnykGroupRoleV1Reference:
    """Reference to SnykGroupRoleV1 model."""

    def get_model_class(self) -> type:
        """Return the model class this reference points to."""
        from clearskies_snyk.models.v1 import snyk_group_role_v1

        return snyk_group_role_v1.SnykGroupRoleV1
